import { http, HttpResponse, delay } from "msw";
import { apiHandlers } from "../mockAPI";

const glue = (requestHandler, delayAmount) => {
  return async (info) => {
    const d = await requestHandler(info);
    let cookie;
    // the only cookie the mockAPI will set is the authorization cookie
    const cookieHeader = d.headers?.["Set-Cookie"];
    if (cookieHeader) {
      const [name, value] = cookieHeader.split(";")[0].split("=");

      cookie = name + "=" + value;
      if (cookieHeader.includes("Max-Age")) {
        cookie += "Max-Age=" + new Date(0);
      }
    }
    let headers = {};
    if (cookie) {
      headers = {
        "Set-Cookie": cookie
      };
    }
    if (delayAmount) {
      console.debug("using delay amount");
      await delay(delayAmount);
      return HttpResponse.json(d.body || {}, {
        status: d.status || 200,
        headers: headers
      });
    } else {
      return HttpResponse.json(d.body || {}, {
        status: d.status || 200,
        headers: headers
      });
    }
  };
};

// define our MSW handlers to mock our API endpoints
export const handlers = apiHandlers.map((h) => {
  const restMap = {
    GET: http.get,
    POST: http.post
  };
  const method = restMap[h.method];
  const isSpec = h.name.includes("spec");
  const delay = h.delay ?? 100;
  return method(h.matcher, glue(h.requestHandler, isSpec ? 0 : delay));
});
